@@ -1,7 +1,10 @@
 use clap::{App, Arg};
 use config::{read_config, Config};
+use error::CorkError;
 use rustyline::error::ReadlineError;
 use rustyline::Editor;
+use std::fs::File;
+use std::io::{self, BufRead};
 use std::path::PathBuf;
 use std::process::exit;
 
@@ -13,6 +16,7 @@ extern crate pest_derive;
 extern crate lazy_static;
 
 mod config;
+mod error;
 mod expression;
 mod format;
 
@@ -36,6 +40,14 @@ fn main() {
                 .takes_value(true)
                 .value_name("PATH")
                 .help("load config file from <PATH>"),
+        )
+        .arg(
+            Arg::with_name("file")
+                .long("file")
+                .short("f")
+                .takes_value(true)
+                .value_name("PATH")
+                .help("load script file to run line by line"),
         );
 
     let matches = app.get_matches();
@@ -50,11 +62,52 @@ fn main() {
 
     if let Some(expr_str) = matches.value_of("expr") {
         inline_evaluate(expr_str, &config);
+    } else if let Some(file_path) = matches.value_of("file") {
+        script_evaluate(file_path, &config);
     } else {
         interactive(&config);
     }
 }
 
+fn script_evaluate(file_path: &str, config: &Config) {
+    let file = File::open(file_path);
+
+    let file = match file {
+        Ok(file) => file,
+        Err(err) => {
+            eprintln!("{}", err);
+            exit(1);
+        }
+    };
+
+    let lines = io::BufReader::new(file).lines();
+
+    let mut ans = 0;
+    let mut of = format::OutputFormat::default();
+    of.set_format_style(*config.output_radix());
+
+    for line in lines {
+        let line = match line {
+            Ok(line) => line,
+            Err(err) => {
+                eprintln!("{}", err);
+                exit(1);
+            }
+        };
+        if line == "warranty" {
+            warranty();
+            continue;
+        }
+        let _ = match proccess_command(line, &mut ans, &mut of) {
+            Ok(_) => continue,
+            Err(e) => {
+                eprintln!("{}", e);
+                exit(1);
+            }
+        };
+    }
+}
+
 fn inline_evaluate(expr_str: &str, config: &Config) {
     match expression::parse_line(expr_str) {
         Ok(command) => match command {
@@ -111,34 +164,11 @@ fn interactive(config: &Config) {
                     warranty();
                     continue;
                 }
-                rl.add_history_entry(line.as_str());
-                match expression::parse_line(&line) {
-                    Ok(command) => match command {
-                        expression::Command::Expr(expr) => {
-                            match expression::eval::eval_expr(&expr, ans) {
-                                Ok(val) => {
-                                    ans = val;
-                                    println!("{}", format::fmt(val, &of));
-                                }
-                                Err(err) => eprintln!("Failed to evaluate \"{}\": {}", line, err),
-                            }
-                        }
-                        expression::Command::Set(set) => {
-                            if set[0] == "of" {
-                                match set[1].as_str() {
-                                    "hex" => of.set_format_style(format::FormatStyle::Hex),
-                                    "dec" => of.set_format_style(format::FormatStyle::Decimal),
-                                    "oct" => of.set_format_style(format::FormatStyle::Octal),
-                                    "bin" => of.set_format_style(format::FormatStyle::Binary),
-                                    _ => eprintln!("Invalid {} value for key {}", set[1], set[0]),
-                                }
-                            } else {
-                                eprintln!("{} is not a valid key", set[0]);
-                            }
-                        }
-                        expression::Command::Empty => println!(),
-                    },
-                    Err(err) => eprintln!("Failed to parse \"{}\": {}", line, err),
+                let _ = match proccess_command(line, &mut ans, &mut of) {
+                    Ok(_) => continue,
+                    Err(e) => {
+                        eprintln!("{}", e);
+                    }
                 };
             }
             Err(ReadlineError::Eof) => {
@@ -158,6 +188,37 @@ fn interactive(config: &Config) {
     rl.save_history(&history_path).unwrap();
 }
 
+fn proccess_command(line: String, ans: &mut i64, of: &mut OutputFormat) -> Result<(), CorkError> {
+    let command = expression::parse_line(&line)?;
+    match command {
+        expression::Command::Expr(expr) => {
+            let val = expression::eval::eval_expr(&expr, *ans)?;
+            *ans = val;
+            println!("{}", format::fmt(val, of));
+        }
+        expression::Command::Set(set) => {
+            if set[0] == "of" {
+                match set[1].as_str() {
+                    "hex" => of.set_format_style(format::FormatStyle::Hex),
+                    "dec" => of.set_format_style(format::FormatStyle::Decimal),
+                    "oct" => of.set_format_style(format::FormatStyle::Octal),
+                    "bin" => of.set_format_style(format::FormatStyle::Binary),
+                    _ => {
+                        return Err(error::CorkError::InvalidValueForKey {
+                            key: set[0].clone(),
+                            value: set[1].clone(),
+                        });
+                    }
+                }
+            } else {
+                return Err(error::CorkError::InvalidKey(set[0].clone()));
+            }
+        }
+        expression::Command::Empty => println!(),
+    };
+    Ok(())
+}
+
 const LICENSE_HEADER: &str = "Copyright (C) 2021 Deep Majumder
 This is free software; see the source code for copying conditions.
 There is ABSOLUTELY NO WARRANTY; not even for MERCHANTABILITY or
@@ -186,7 +247,7 @@ fn welcome() {
 }
 
 fn version() -> &'static str {
-    "0.2.0"
+    "0.2.1"
 }
 
 fn warranty() {
